/**
 * 
 */
package org.gcube.resourcemanagement.model.reference.entities.resources;

import org.gcube.informationsystem.types.annotations.ResourceSchema;
import org.gcube.informationsystem.types.annotations.ResourceSchemaEntry;
import org.gcube.resourcemanagement.model.impl.entities.resources.DatasetImpl;
import org.gcube.resourcemanagement.model.reference.entities.facets.AccessPointFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.ContactFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.CoverageFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.DescriptiveMetadataFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.EventFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.IdentifierFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.LicenseFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.ProvenanceFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.SubjectFacet;
import org.gcube.resourcemanagement.model.reference.relations.consistsof.HasContact;
import org.gcube.resourcemanagement.model.reference.relations.consistsof.HasContributor;
import org.gcube.resourcemanagement.model.reference.relations.consistsof.HasCoverage;
import org.gcube.resourcemanagement.model.reference.relations.consistsof.HasCreator;
import org.gcube.resourcemanagement.model.reference.relations.consistsof.HasCurator;
import org.gcube.resourcemanagement.model.reference.relations.consistsof.HasMaintainer;
import org.gcube.resourcemanagement.model.reference.relations.consistsof.HasOwner;
import org.gcube.resourcemanagement.model.reference.relations.consistsof.HasSpatialCoverage;
import org.gcube.resourcemanagement.model.reference.relations.consistsof.HasTemporalCoverage;
import org.gcube.resourcemanagement.model.reference.relations.consistsof.IsIdentifiedBy;

import com.fasterxml.jackson.databind.annotation.JsonDeserialize;

/**
 * @author Luca Frosini (ISTI - CNR)
 * https://wiki.gcube-system.org/gcube/Facet_Based_Resource_Model#Dataset
 */
@JsonDeserialize(as=DatasetImpl.class)
@ResourceSchema({
	@ResourceSchemaEntry(consistOfType=IsIdentifiedBy.class, targetFacetType=IdentifierFacet.class, min=1),
	@ResourceSchemaEntry(consistOfType=HasContact.class, targetFacetType=ContactFacet.class, min=1),
	@ResourceSchemaEntry(consistOfType=HasContributor.class, targetFacetType=ContactFacet.class),
	@ResourceSchemaEntry(consistOfType=HasCreator.class, targetFacetType=ContactFacet.class),
	@ResourceSchemaEntry(consistOfType=HasCurator.class, targetFacetType=ContactFacet.class),
	@ResourceSchemaEntry(consistOfType=HasMaintainer.class, targetFacetType=ContactFacet.class),
	@ResourceSchemaEntry(consistOfType=HasOwner.class, targetFacetType=ContactFacet.class),
	@ResourceSchemaEntry(targetFacetType=AccessPointFacet.class),
	@ResourceSchemaEntry(targetFacetType=LicenseFacet.class),
	@ResourceSchemaEntry(targetFacetType=EventFacet.class),
	@ResourceSchemaEntry(targetFacetType=ProvenanceFacet.class),
	@ResourceSchemaEntry(consistOfType=HasCoverage.class, targetFacetType=CoverageFacet.class, min=1),
	@ResourceSchemaEntry(consistOfType=HasTemporalCoverage.class, targetFacetType=CoverageFacet.class),
	@ResourceSchemaEntry(consistOfType=HasSpatialCoverage.class, targetFacetType=CoverageFacet.class),
	@ResourceSchemaEntry(targetFacetType=DescriptiveMetadataFacet.class),
	@ResourceSchemaEntry(targetFacetType=SubjectFacet.class)
})
public interface Dataset extends GCubeResource {

	public static final String NAME = "Dataset"; // Dataset.class.getSimpleName();
	public static final String DESCRIPTION = "Collect Dataset information through the list of its facets";
	public static final String VERSION = "1.0.0";
	
}
