/**
 * 
 */
package org.gcube.resourcemanagement.model.reference.entities.resources;

import org.gcube.informationsystem.types.annotations.ResourceSchema;
import org.gcube.informationsystem.types.annotations.ResourceSchemaEntry;
import org.gcube.resourcemanagement.model.impl.entities.resources.EServiceImpl;
import org.gcube.resourcemanagement.model.reference.entities.facets.AccessPointFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.EventFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.LicenseFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.ServiceStateFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.SoftwareFacet;
import org.gcube.resourcemanagement.model.reference.relations.consistsof.IsIdentifiedBy;

import com.fasterxml.jackson.databind.annotation.JsonDeserialize;

/**
 * @author Luca Frosini (ISTI - CNR)
 * https://wiki.gcube-system.org/gcube/Facet_Based_Resource_Model#E-Service
 */
@JsonDeserialize(as=EServiceImpl.class)
@ResourceSchema({
	@ResourceSchemaEntry(consistOfType=IsIdentifiedBy.class, targetFacetType=SoftwareFacet.class, min=1),
	@ResourceSchemaEntry(targetFacetType=SoftwareFacet.class),
	@ResourceSchemaEntry(targetFacetType=AccessPointFacet.class, min=1),
	@ResourceSchemaEntry(targetFacetType=EventFacet.class, min=1, max=1),
	@ResourceSchemaEntry(targetFacetType=ServiceStateFacet.class, min=1, max=1),
	@ResourceSchemaEntry(targetFacetType=LicenseFacet.class)
})
public interface EService extends Service {
	
	public static final String NAME = "EService"; // EService.class.getSimpleName();
	public static final String DESCRIPTION = "Collect Electronic Service (aka Running Service) information through the list of its facets";
	public static final String VERSION = "1.0.0";
	
	public static EService getInstance() {
		return new EServiceImpl();
	}
	
}
