/**
 * 
 */
package org.gcube.resourcemanagement.model.reference.entities.resources;

import org.gcube.informationsystem.types.annotations.ResourceSchema;
import org.gcube.informationsystem.types.annotations.ResourceSchemaEntry;
import org.gcube.resourcemanagement.model.impl.entities.resources.SchemaImpl;
import org.gcube.resourcemanagement.model.reference.entities.facets.ContactFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.DescriptiveMetadataFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.JSONSchemaFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.SchemaFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.SubjectFacet;
import org.gcube.resourcemanagement.model.reference.entities.facets.XSDSchemaFacet;
import org.gcube.resourcemanagement.model.reference.relations.consistsof.HasContact;
import org.gcube.resourcemanagement.model.reference.relations.consistsof.IsIdentifiedBy;

import com.fasterxml.jackson.databind.annotation.JsonDeserialize;

/**
 * @author Luca Frosini (ISTI - CNR)
 * https://wiki.gcube-system.org/gcube/Facet_Based_Resource_Model#Schema
 */
@JsonDeserialize(as=SchemaImpl.class)
@ResourceSchema({
	@ResourceSchemaEntry(consistOfType=IsIdentifiedBy.class, targetFacetType=SchemaFacet.class, min=1),
	@ResourceSchemaEntry(consistOfType=IsIdentifiedBy.class, targetFacetType=JSONSchemaFacet.class),
	@ResourceSchemaEntry(consistOfType=IsIdentifiedBy.class, targetFacetType=XSDSchemaFacet.class),
	@ResourceSchemaEntry(consistOfType=HasContact.class, targetFacetType=ContactFacet.class, min=1),
	@ResourceSchemaEntry(targetFacetType=DescriptiveMetadataFacet.class),
	@ResourceSchemaEntry(targetFacetType=SubjectFacet.class)
})
public interface Schema extends GCubeResource {
	
	public static final String NAME = "Schema"; // Schema.class.getSimpleName();
	public static final String DESCRIPTION = "Collect Schema information through the list of its facets";
	public static final String VERSION = "1.0.0";
}
